@@ -1,4 +1,5 @@
 """Defines parsing functions used by isort for parsing import definitions"""
+import re
 from collections import OrderedDict, defaultdict
 from functools import partial
 from itertools import chain
@@ -36,18 +37,18 @@ def _infer_line_separator(contents: str) -> str:
     return "\n"
 
 
-def _normalize_line(raw_line: str) -> Tuple[str, str]:
+def normalize_line(raw_line: str) -> Tuple[str, str]:
     """Normalizes import related statements in the provided line.
 
     Returns (normalized_line: str, raw_line: str)
     """
-    line = raw_line.replace("from.import ", "from . import ")
-    line = line.replace("from.cimport ", "from . cimport ")
+    line = re.sub(r"from(\.+)cimport ", r"from \g<1> cimport ", raw_line)
+    line = re.sub(r"from(\.+)import ", r"from \g<1> import ", line)
     line = line.replace("import*", "import *")
-    line = line.replace(" .import ", " . import ")
-    line = line.replace(" .cimport ", " . cimport ")
+    line = re.sub(r" (\.+)import ", r" \g<1> import ", line)
+    line = re.sub(r" (\.+)cimport ", r" \g<1> cimport ", line)
     line = line.replace("\t", " ")
-    return (line, raw_line)
+    return line, raw_line
 
 
 def import_type(line: str, config: Config = DEFAULT_CONFIG) -> Optional[str]:
@@ -63,7 +64,7 @@ def import_type(line: str, config: Config = DEFAULT_CONFIG) -> Optional[str]:
     return None
 
 
-def _strip_syntax(import_string: str) -> str:
+def strip_syntax(import_string: str) -> str:
     import_string = import_string.replace("_import", "[[i]]")
     import_string = import_string.replace("_cimport", "[[ci]]")
     for remove_syntax in ["\\", "(", ")", ","]:
@@ -263,7 +264,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
             statements[-1] = f"{statements[-1]}#{end_of_line_comment[0]}"
 
         for statement in statements:
-            line, raw_line = _normalize_line(statement)
+            line, raw_line = normalize_line(statement)
             type_of_import = import_type(line, config) or ""
             raw_lines = [raw_line]
             if not type_of_import:
@@ -275,7 +276,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
             nested_comments = {}
             import_string, comment = parse_comments(line)
             comments = [comment] if comment else []
-            line_parts = [part for part in _strip_syntax(import_string).strip().split(" ") if part]
+            line_parts = [part for part in strip_syntax(import_string).strip().split(" ") if part]
             if type_of_import == "from" and len(line_parts) == 2 and comments:
                 nested_comments[line_parts[-1]] = comments[0]
 
@@ -285,7 +286,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                     index += 1
                     if new_comment:
                         comments.append(new_comment)
-                    stripped_line = _strip_syntax(line).strip()
+                    stripped_line = strip_syntax(line).strip()
                     if (
                         type_of_import == "from"
                         and stripped_line
@@ -309,7 +310,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                         and ")" not in line.split("#")[0]
                         and index < line_count
                     ):
-                        stripped_line = _strip_syntax(line).strip()
+                        stripped_line = strip_syntax(line).strip()
                         if (
                             type_of_import == "from"
                             and stripped_line
@@ -325,7 +326,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                             index += 1
                             if new_comment:
                                 comments.append(new_comment)
-                            stripped_line = _strip_syntax(line).strip()
+                            stripped_line = strip_syntax(line).strip()
                             if (
                                 type_of_import == "from"
                                 and stripped_line
@@ -336,7 +337,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
                             import_string += line_separator + line
                             raw_lines.append(line)
 
-                    stripped_line = _strip_syntax(line).strip()
+                    stripped_line = strip_syntax(line).strip()
                     if (
                         type_of_import == "from"
                         and stripped_line
@@ -377,7 +378,7 @@ def file_contents(contents: str, config: Config = DEFAULT_CONFIG) -> ParsedConte
 
             just_imports = [
                 item.replace("{|", "{ ").replace("|}", " }")
-                for item in _strip_syntax(import_string).split()
+                for item in strip_syntax(import_string).split()
             ]
 
             attach_comments_to: Optional[List[Any]] = None
